<?php
/**
 * Plugin Google Maps: Allow Display of a Google Map in a wiki page.
 * 
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Christopher Smith <chris@jalakai.co.uk>
 */
 
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 

// ---------- [ Settings ] -----------------------------------------
define('GMAP_KEY','ABQIAAAAaGiwFwzKGW59ARottwczvxTF5BJFY1KOxg4ylCXnlrNPYalHPBTyNNcnXNC6neaTMSKfc5_A_SVrug');
define('GMAP_SCRIPT','http://maps.google.com/maps?file=api&amp;v=1&amp;key='.GMAP_KEY);

/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_googlemaps extends DokuWiki_Syntax_Plugin {

    var $dflt = array(
      'type' => 'map',
      'width' => '',
      'height' => '',
      'lat'  => -4.25,
      'lon' => 55.833,
      'zoom' => 8,
      'controls' => 'on'
    );
    
    function getInfo(){
      return array(
        'author' => 'Christopher Smith',
        'email'  => 'chris@jalakai.co.uk',
        'date'   => '2006-02-18',
        'name'   => 'Google Maps Plugin',
        'desc'   => 'Remove one level of indenting
                     Syntax: <gmap>options</gmap>',
        'url'    => 'http://wiki.splitbrain.org/plugin:googlemaps',
      );
    }
 
    function getType() { return 'substition'; }
    function getSort() { return 900; } 
    
    function connectTo($mode) { 
        $this->Lexer->addSpecialPattern('<gmap>.*?</gmap>',$mode,'plugin_googlemaps'); 
    }
    
    function handle($match, $state, $pos, &$handler){
    
      // parse match for instructions, break into key value pairs
      $param = explode('|', substr($match, 6, -7));
      
      $gmap = $this->dflt;
      foreach($param as $kvpair) {
        list($key,$val) = explode('=',$kvpair);
        $key = strtolower($key);
        if (isset($gmap[$key])) $gmap[$key] = strtolower($val);        
      }
      
      if ($gmap['width'] || $gmap['height']) {
        $style = $gmap['width'] ? 'width: '.$gmap['width'].";" : "";
        $style .= $gmap['height'] ? 'height: '.$gmap['height'].";" : "";
        $style = "style='$style'";
      } else {
        $style = '';
      }      
      
      unset($gmap['width'],$gmap['height']);
      
      $param = '';
      foreach ($gmap as $key => $val) {
          $param .= is_numeric($val) ? "$key : $val," : "$key : '".htmlspecialchars($val)."',";
      }
      $param = "googlemap[googlemap.length] = { ".substr($param,0,-1)." };";
      
      return array($style, $param);
    }
    
    function render($mode, &$renderer, $data) {
    
      static $initialised = false;    // set to true after script initialisation
      
      list($style, $param) = $data;
    
      $script = '';
      
      if (!$initialised) {
        $initialised = true;
        $script = '<script type="text/javascript" src="'.GMAP_SCRIPT.'"></script>';
      }
      
      $renderer->doc .= "
<div class='googlemap' $style>
$script
<script type='text/javascript'>
$param
</script>
</div>";
      return false;
    } 
}
